@@ -1,5 +1,5 @@
 /* gc.h --- Header file for implementation agnostic crypto wrapper API.
- * Copyright (C) 2002, 2003, 2004, 2005, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2007, 2008  Simon Josefsson
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published
@@ -48,7 +48,8 @@ enum Gc_hash
   GC_RMD160,
   GC_SHA256,
   GC_SHA384,
-  GC_SHA512
+  GC_SHA512,
+  GC_SHA224
 };
 typedef enum Gc_hash Gc_hash;
 
@@ -68,6 +69,7 @@ typedef void *gc_hash_handle;
 #define GC_SHA256_DIGEST_SIZE 32
 #define GC_SHA384_DIGEST_SIZE 48
 #define GC_SHA512_DIGEST_SIZE 64
+#define GC_SHA224_DIGEST_SIZE 24
 
 /* Cipher types. */
 enum Gc_cipher
