@@ -25,10 +25,11 @@
 
 #include <stddef.h>		/* size_t */
 #include <stdio.h>		/* FILE */
+#include <stdarg.h>		/* va_list */
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.36"
+#define SHISHI_VERSION "0.0.37"
 
 /* Error codes */
 typedef enum
@@ -544,7 +545,8 @@ Shishi_krb_error;
 
 typedef enum
 {
-  SHISHI_TKTSHINTFLAGS_ACCEPT_EXPIRED = 1
+  SHISHI_TKTSHINTFLAGS_ACCEPT_EXPIRED = 1,
+  SHISHI_TKTSHINTFLAGS_NON_INTERACTIVE = 2
 }
 Shishi_tkts_hintflags;
 
@@ -608,10 +610,11 @@ typedef struct Shishi_key Shishi_key;
 typedef struct Shishi_keys Shishi_keys;
 typedef struct Shishi_safe Shishi_safe;
 typedef struct Shishi_priv Shishi_priv;
-#ifndef _SHISHI_HAS_LIBTASN1_H
-typedef struct node_asn_struct *ASN1_TYPE;
-#endif
+#ifdef LIBTASN1_H
 typedef ASN1_TYPE Shishi_asn1;
+#else
+typedef void *Shishi_asn1;
+#endif
 typedef struct Shishi_crypto Shishi_crypto;
 
 #define SHISHI_GENERALIZEDTIME_LENGTH 15
@@ -892,16 +895,16 @@ extern int shishi_ticket_save (Shishi * handle, FILE * fh,
 			       Shishi_asn1 ticket);
 extern int shishi_ticket_print (Shishi * handle, FILE * fh,
 				Shishi_asn1 ticket);
-extern int shishi_kdc_req_print (Shishi * handle, FILE * fh,
-				 Shishi_asn1 asreq);
-extern int shishi_kdc_rep_print (Shishi * handle, FILE * fh,
-				 Shishi_asn1 asreq);
+extern int shishi_kdcreq_print (Shishi * handle, FILE * fh,
+				Shishi_asn1 kdcreq);
+extern int shishi_kdcrep_print (Shishi * handle, FILE * fh,
+				Shishi_asn1 kdcrep);
 extern int shishi_kdc_print (Shishi * handle, FILE * fh, Shishi_asn1 asreq,
 			     Shishi_asn1 asrep, Shishi_asn1 encasreppart);
-extern int shishi_kdc_req_parse (Shishi * handle, FILE * fh,
-				 Shishi_asn1 * asreq);
-extern int shishi_kdc_rep_parse (Shishi * handle, FILE * fh,
-				 Shishi_asn1 * asrep);
+extern int shishi_kdcreq_parse (Shishi * handle, FILE * fh,
+				Shishi_asn1 * kdcreq);
+extern int shishi_kdcrep_parse (Shishi * handle, FILE * fh,
+				Shishi_asn1 * kdcrep);
 extern int shishi_ticket_parse (Shishi * handle, FILE * fh,
 				Shishi_asn1 * ticket);
 extern int shishi_ticket_read (Shishi * handle, FILE * fh,
@@ -1037,9 +1040,6 @@ extern void shishi_as_rep_set (Shishi_as * as, Shishi_asn1 asrep);
 extern int shishi_as_rep_build (Shishi_as * as, Shishi_key * key);
 extern int shishi_as_rep_der (Shishi_as * as, char **out, size_t * outlen);
 extern int shishi_as_rep_der_set (Shishi_as * as, char *der, size_t derlen);
-extern Shishi_asn1 shishi_as_encasreppart (Shishi_as * as);
-extern void shishi_as_encasreppart_set (Shishi_as * as,
-					Shishi_asn1 encasreppart);
 extern Shishi_asn1 shishi_as_krberror (Shishi_as * as);
 extern int shishi_as_krberror_der (Shishi_as * as, char **out,
 				   size_t * outlen);
@@ -1600,6 +1600,15 @@ extern int shishi_crypto_decrypt (Shishi_crypto * ctx,
 extern const char *shishi_check_version (const char *req_version);
 
 /* password.c */
+typedef int (*shishi_prompt_password_func) (Shishi * handle,
+					    char **s,
+					    const char *format,
+					    va_list ap);
+extern void
+shishi_prompt_password_callback_set (Shishi * handle,
+				     shishi_prompt_password_func cb);
+extern shishi_prompt_password_func
+shishi_prompt_password_callback_get (Shishi * handle);
 extern int
 shishi_prompt_password (Shishi * handle, char **s, const char *format, ...);
 
@@ -1668,12 +1677,15 @@ extern Shishi_asn1 shishi_asn1_encprivpart (Shishi * handle);
 extern int shishi_asn1_to_der (Shishi * handle, Shishi_asn1 node,
 			       char **der, size_t * len);
 extern int shishi_asn1_to_der_field (Shishi * handle, Shishi_asn1 node,
-				     const char *field, char **der, size_t * len);
+				     const char *field,
+				     char **der, size_t * len);
 
 extern Shishi_msgtype shishi_asn1_msgtype (Shishi * handle, Shishi_asn1 node);
 extern Shishi_msgtype shishi_der_msgtype (Shishi * handle,
 					  const char *der, size_t derlen);
 
+extern void shishi_asn1_print (Shishi * handle, Shishi_asn1 node, FILE * fh);
+
 extern Shishi_asn1 shishi_der2asn1 (Shishi * handle,
 				    const char *der, size_t derlen);
 extern Shishi_asn1 shishi_der2asn1_padata (Shishi * handle,
