@@ -1,5 +1,5 @@
 /* utils.c --- Shishi self tests utilities.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -34,6 +34,8 @@
 #include <sys/socket.h>
 #include <unistd.h>
 #include <string.h>
+#include <sys/time.h>
+#include <time.h>
 
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
@@ -55,24 +57,9 @@
 #include <errno.h>
 #endif
 
-#if TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# if HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
-
-#ifdef HAVE_SIGNAL_H
 #include <signal.h>
-#endif
 
-#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
-#endif
 #ifdef HAVE_NETINET_IN6_H
 #include <netinet/in6.h>
 #endif
@@ -125,9 +112,9 @@ escapeprint (const char *str, int len)
     if ((str[i] >= 'A' && str[i] <= 'Z') ||
 	(str[i] >= 'a' && str[i] <= 'z') ||
 	(str[i] >= '0' && str[i] <= '9') || str[i] == '.')
-      printf ("%c", str[i]);
+      printf ("%c", str[i] & 0xFF);
     else
-      printf ("\\x%02x", str[i]);
+      printf ("\\x%02x", str[i] & 0xFF);
   printf ("' (length %d bytes)\n", len);
 }
 
@@ -142,7 +129,7 @@ hexprint (const char *str, int len)
   printf ("\t ;; ");
   for (i = 0; i < len; i++)
     {
-      printf ("%02x ", str[i]);
+      printf ("%02x ", str[i] & 0xFF);
       if ((i + 1) % 8 == 0)
 	printf (" ");
       if ((i + 1) % 16 == 0 && i + 1 < len)
